@@ -248,12 +248,11 @@ void TorrentFileTreeModel::Node::saveExpandedState(const QModelIndex &index, QSo
     }
 }
 
-void TorrentFileTreeModel::Node::loadExpandedState(const QModelIndex &index, QSortFilterProxyModel *pm, QTreeView *tv, BNode *n)
+void TorrentFileTreeModel::Node::loadExpandedState(const QModelIndex &index, QSortFilterProxyModel *pm, QTreeView *tv, BDictNode *dict)
 {
     if (file)
         return;
 
-    auto *dict = dynamic_cast<BDictNode *>(n);
     if (!dict)
         return;
 
@@ -584,7 +583,7 @@ QByteArray TorrentFileTreeModel::saveExpandedState(QSortFilterProxyModel *pm, QT
         return QByteArray();
 
     QByteArray data;
-    BEncoder enc(new BEncoderBufferOutput(data));
+    BEncoder enc(std::make_unique<BEncoderBufferOutput>(data));
     enc.beginDict();
     root->saveExpandedState(index(0, 0, QModelIndex()), pm, tv, &enc);
     enc.end();
@@ -597,11 +596,10 @@ void TorrentFileTreeModel::loadExpandedState(QSortFilterProxyModel *pm, QTreeVie
         return;
 
     BDecoder dec(state, false, 0);
-    BNode *n = dec.decode();
-    if (n && n->getType() == BNode::DICT) {
-        root->loadExpandedState(index(0, 0, QModelIndex()), pm, tv, n);
+    const std::unique_ptr<BDictNode> dict = dec.decodeDict();
+    if (dict) {
+        root->loadExpandedState(index(0, 0, QModelIndex()), pm, tv, dict.get());
     }
-    delete n;
 }
 
 bt::TorrentFileInterface *TorrentFileTreeModel::indexToFile(const QModelIndex &idx)
