@@ -25,6 +25,9 @@
 #include <QFile>
 
 #include <KIO/DeleteJob>
+#include <KIO/FileCopyJob>
+#include <KIO/ListJob>
+
 #include <QStandardPaths>
 
 ChecksumSearchController ChecksumSearchTransferDataSource::s_controller;
@@ -197,7 +200,9 @@ void ChecksumSearchTransferDataSource::gotBaseUrl(const QUrl &urlToFile)
     if (urls.count() && types.count()) {
         auto *search = new ChecksumSearch(urls, m_sourceUrl.fileName(), types);
 
-        connect(search, SIGNAL(data(QString, QString)), this, SIGNAL(data(QString, QString)));
+        connect(search, &ChecksumSearch::data, this, [this](QString type, QString checksum) {
+            this->data(type, checksum);
+        });
     }
 }
 
