@@ -12,10 +12,10 @@
 
 #include "metalinksettings.h"
 
-#include "kget_macro.h"
-#include <kpluginmetadata.h>
+#include <KPluginFactory>
+#include <KPluginMetaData>
 
-KGET_EXPORT_PLUGIN_CONFIG(DlgSettingsWidget)
+K_PLUGIN_CLASS(DlgSettingsWidget)
 
 DlgSettingsWidget::DlgSettingsWidget(QObject *parent, const KPluginMetaData &data)
     : KCModule(parent, data)
