@@ -111,20 +111,12 @@ bool Metalink::metalinkInit(const QUrl &src, const QByteArray &data)
 
     // offers a dialog to download the newest version of a dynamic metalink
     if ((m_source.isLocalFile() || !m_metalinkJustDownloaded) && m_metalink.dynamic && (UrlChecker::checkSource(m_metalink.origin) == UrlChecker::NoError)) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::questionTwoActions(nullptr,
-#else
-        if (KMessageBox::questionYesNo(nullptr,
-#endif
                                             i18n("A newer version of this Metalink might exist, do you want to download it?"),
                                             i18n("Redownload Metalink"),
                                             KGuiItem(i18nc("@action:button", "Download Again"), QStringLiteral("view-refresh")),
                                             KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             == KMessageBox::PrimaryAction) {
-#else
-            == KMessageBox::Yes) {
-#endif
             m_localMetalinkLocation.clear();
             m_source = m_metalink.origin;
             downloadMetalink();
@@ -456,23 +448,14 @@ void Metalink::slotVerified(bool isVerified)
         }
 
         if (brokenFiles.count()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (KMessageBox::warningTwoActionsList(
                     nullptr,
-#else
-            if (KMessageBox::warningYesNoList(
-                    nullptr,
-#endif
                     i18n("The download could not be verified, do you want to repair (if repairing does not work the download would be restarted) it?"),
                     brokenFiles,
                     QString(),
                     KGuiItem(i18nc("@action:button", "Repair")),
                     KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 == KMessageBox::PrimaryAction) {
-#else
-                == KMessageBox::Yes) {
-#endif
                 if (repair()) {
                     return;
                 }
